@@ -26,7 +26,7 @@ class AiDefaultNormalGui : public PlayerGui
 {
 public:
     explicit AiDefaultNormalGui();
-    virtual Player* createInstance(Game *game, const QString &newName, const QColor &color) const;
+    Player* createInstance(Game *game, const QString &newName, const QColor &color) const override;
 };
 
 #endif // AI_DEFAULT_NORMAL_GUI_H
